Macaulay2 » Documentation
Packages » K3Carpets :: carpetBettiTable
next | previous | forward | backward | up | index | toc

carpetBettiTable -- compute the Betti tables of a carpet of given genus and Clifford index over a prime field of characteristic p

Description

We compute the equation and nonminimal resolution F of the carpet of type (a,b) where $a \ge b$ over a larger finite prime field, lift the complex to the integers, which is possible since the coefficients are small. Finally we study the nonminimal strands over ZZ by computing the Smith normal form. The resulting data allow us to compute the Betti tables for arbitrary primes.

i1 : a=5,b=5

o1 = (5, 5)

o1 : Sequence
i2 : elapsedTime T=carpetBettiTable(a,b,3)
 -- .0199073s elapsed
 -- .00417134s elapsed
 -- .0146791s elapsed
 -- .00630762s elapsed
 -- .0023799s elapsed
 -- .209675s elapsed

            0  1   2   3   4   5   6   7  8 9
o2 = total: 1 36 160 315 302 302 315 160 36 1
         0: 1  .   .   .   .   .   .   .  . .
         1: . 36 160 315 288  14   .   .  . .
         2: .  .   .   .  14 288 315 160 36 .
         3: .  .   .   .   .   .   .   .  . 1

o2 : BettiTally
i3 : J=canonicalCarpet(a+b+1,b,Characteristic=>3);

              ZZ
o3 : Ideal of --[x ..x , y ..y ]
               3  0   5   0   5
i4 : elapsedTime T'=minimalBetti J
 -- .127467s elapsed

            0  1   2   3   4   5   6   7  8 9
o4 = total: 1 36 160 315 302 302 315 160 36 1
         0: 1  .   .   .   .   .   .   .  . .
         1: . 36 160 315 288  14   .   .  . .
         2: .  .   .   .  14 288 315 160 36 .
         3: .  .   .   .   .   .   .   .  . 1

o4 : BettiTally
i5 : T-T'

            0 1 2 3 4 5 6 7 8 9
o5 = total: . . . . . . . . . .
         1: . . . . . . . . . .
         2: . . . . . . . . . .
         3: . . . . . . . . . .

o5 : BettiTally
i6 : elapsedTime h=carpetBettiTables(6,6);
 -- .00308274s elapsed
 -- .0111257s elapsed
 -- .0596088s elapsed
 -- .605587s elapsed
 -- .274204s elapsed
 -- .0239245s elapsed
 -- .00451002s elapsed
 -- 3.01069s elapsed
i7 : carpetBettiTable(h,7)

            0  1   2   3    4    5    6    7   8   9 10 11
o7 = total: 1 55 320 891 1408 1155 1155 1408 891 320 55  1
         0: 1  .   .   .    .    .    .    .   .   .  .  .
         1: . 55 320 891 1408 1155    .    .   .   .  .  .
         2: .  .   .   .    .    . 1155 1408 891 320 55  .
         3: .  .   .   .    .    .    .    .   .   .  .  1

o7 : BettiTally
i8 : carpetBettiTable(h,5)

            0  1   2   3    4    5    6    7   8   9 10 11
o8 = total: 1 55 320 891 1408 1275 1275 1408 891 320 55  1
         0: 1  .   .   .    .    .    .    .   .   .  .  .
         1: . 55 320 891 1408 1155  120    .   .   .  .  .
         2: .  .   .   .    .  120 1155 1408 891 320 55  .
         3: .  .   .   .    .    .    .    .   .   .  .  1

o8 : BettiTally

See also

Ways to use carpetBettiTable:

  • carpetBettiTable(HashTable,ZZ)
  • carpetBettiTable(ZZ,ZZ,ZZ)

For the programmer

The object carpetBettiTable is a method function.


The source of this document is in K3Carpets.m2:1498:0.